# fwdpp - A C++ template library for forward-time population genetic simulations

# Documentation

See the [reference manual](https://fwdpp.readthedocs.io).

# fwdpp-users mailing list

There is a [Google Group](https://groups.google.com/forum/#!forum/fwdpp-users) for fwdpp users.
In practice, this group hasn't been very active.
Most discussion has happened via other channels.

# Build status

* Status of main branch: [![CircleCI](https://circleci.com/gh/molpopgen/fwdpp/tree/main.svg?style=svg)](https://circleci.com/gh/molpopgen/fwdpp/tree/main)
* Status of dev branch:  [![CircleCI](https://circleci.com/gh/molpopgen/fwdpp/tree/dev.svg?style=svg)](https://circleci.com/gh/molpopgen/fwdpp/tree/dev)
